;+
; NAME:
;  astlinks
; PURPOSE:
;  Scan for linkages among a collection of asteroid astrometric measurements
; DESCRIPTION:
;
; CATEGORY:
;  Astrometry
; CALLING SEQUENCE:
;  astlinks,otherdir
; INPUTS:
;
; OPTIONAL INPUT PARAMETERS:
;  otherdir - If specified, the local .ast files are checked against this
;               directory too.
; KEYWORD INPUT PARAMETERS:
;
; OUTPUTS:
;
; KEYWORD OUTPUT PARAMETERS:
;
; COMMON BLOCKS:
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
;  98/01/13, Written by Marc W. Buie, Lowell Observatory
;
;-
PRO astlinks,in_otherdir

   if badpar(in_otherdir,[0,7],0,caller='REDUCTOR: (DUMPOBJ) ', $
                                 default='.') then return

   otherdir=in_otherdir

   blanks='                                             '

   spawn,'ls *.ast',localfn
   IF localfn[0] eq '' THEN BEGIN
      print,'No astrometry files found in current directory.  Aborting.'
      return
   ENDIF

   IF otherdir ne '.' THEN BEGIN
      spawn,'ls '+addslash(otherdir)+'*.ast',otherfn
      IF otherfn[0] eq '' THEN otherdir='.'
   ENDIF

   nlocal=n_elements(localfn)
   cr = string("15b)  ;"
   rt = string("12b)  ;"
   form='($,a,a15,1x,i5)'

   FOR i=0,nlocal-1 DO BEGIN

      print,form=form,cr,localfn[i]+blanks,nlocal-i
      rdrawast,localfn[i],fn0,jd0,ra0,dec0,mag0,nobs0

      ; Compute rate of first object
      objdir0 = atan(dec0[nobs0-1]-dec0[0],ra0[0]-ra0[nobs0-1])*!radeg
      hmotobj0=angsep(ra0[0],dec0[0],ra0[nobs0-1],dec0[nobs0-1]) $
           / (abs(jd0[nobs0-1]-jd0[0]) * 24.0 ) * !radeg * 3600.0

      IF otherdir eq '.' THEN BEGIN
         cklist = localfn[i:*]
      ENDIF ELSE BEGIN
         cklist = [localfn[i:*],otherfn]
      ENDELSE

      FOR j=0,n_elements(cklist)-1 DO BEGIN

         ckobj=cklist[j]
         loc=rstrpos(ckobj,'/')
         IF loc ne -1 THEN BEGIN
            ckobj = strmid(ckobj,loc+1,99)
         ENDIF

         IF ckobj ne localfn[i] THEN BEGIN

            rdrawast,cklist[j],fn1,jd1,ra1,dec1,mag1,nobs1
            ; Compute rate of second object
            objdir1 = atan(dec1[nobs1-1]-dec1[0],ra1[0]-ra1[nobs1-1])*!radeg
            hmotobj1=angsep(ra1[0],dec1[0],ra1[nobs1-1],dec1[nobs1-1]) $
                 / (abs(jd1[nobs1-1]-jd1[0]) * 24.0 ) * !radeg * 3600.0

            ; Compute rate assuming both 1st measures are same object
            IF jd0[0] eq jd1[0] THEN BEGIN
               hmotobj2=9999.0
            ENDIF ELSE BEGIN
               hmotobj2=angsep(ra0[0],dec0[0],ra1[0],dec1[0]) $
                    / (abs(jd1[0]-jd0[0]) * 24.0 ) * !radeg * 3600.0
            ENDELSE

            closerate = abs(hmotobj0-hmotobj1) lt 2.0 and $
                        abs(hmotobj0-hmotobj2) lt 2.0

            closedir  = abs(objdir0-objdir1) lt 5.0

            IF not closedir and objdir0 lt 0.0 THEN $
               closedir = abs((objdir0+360.0)-objdir1) lt 5.0

            IF closerate and closedir THEN BEGIN
               print,''
               print,localfn[i]+blanks,hmotobj0,objdir0,minmax(mag0), $
                  format='(2x,"[",a30,1x,f6.1,"aph ",f6.1,"d]",2(1x,f4.1))'
               print,cklist[j]+blanks,hmotobj1,objdir1,minmax(mag0),hmotobj2, $
                  format='(2x,"[",a30,1x,f6.1,"aph ",f6.1,"d]",2(1x,f4.1),2x,f6.1,"aph")'
               print,''
            ENDIF

         ENDIF

      ENDFOR

   ENDFOR

print,''
END
