;+
; NAME: 
;  mkbias
; PURPOSE: 
;  Collect and combine CCD bias frames into a superbias frame
; DESCRIPTION:
; CATEGORY:
;  CCD data processing
; CALLING SEQUENCE:
;  mkbias,root,outsuf,start,nframes
; INPUTS:
; OPTIONAL INPUT PARAMETERS:
; KEYWORD INPUT PARAMETERS:
; OUTPUTS:
; KEYWORD OUTPUT PARAMETERS:
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;  95/03/09 - Initial crude version written, Marc W. Buie, Lowell Observatory
;  95/06/13, MWB, added OVERSCAN and CROP keywords
;  95/11/22, MWB, add EXCLUDE keyword
;-
pro mkbias,root,outsuf,start,nframes,bias, $
       OVERSCAN=overscan,CROP=crop,EXCLUDE=exclude

on_error,2

if badpar(root,   7,    0,caller='MKBIAS: (root) '   ) then return
if badpar(outsuf, 7,    0,caller='MKBIAS: (outsuf) ' ) then return
if badpar(start,  [2,3],[0,1],caller='MKBIAS: (start) ',rank=start_rank  ) then return
if badpar(nframes,[2,3],0,caller='MKBIAS: (nframes) ') then return
if badpar(overscan,[0,2,3],1,caller='MKBIAS: (overscan) ') then return
if badpar(exclude,[0,2,3],[0,1],caller='MKBIAS: (exclude) ',default=-1) then return
if badpar(crop,[0,2,3],1,caller='MKBIAS: (crop) ') then return

if start_rank eq 0 then begin
   frames=start+indgen(nframes)
endif else begin
   frames=start
   nframes=n_elements(frames)
endelse
print,'Load frames ',min(frames),' to ',max(frames)
for i=0,nframes-1 do begin
   z=where(frames[i] eq exclude,count)
   if count ne 0 then frames[i]=-1
endfor
z=where(frames ne -1,count)
if count eq 0 then $
   message,'Error ** you have excluded all frames, nothing to do.'

fname=root+string(frames[z[0]],format='(i3.3)')
first = readfits(fname,hdr,/silent)
sz=size(first)
firstframe=frames[z[0]]

if keyword_set(overscan) and keyword_set(crop) then begin
   firstn = colbias(first,overscan[0],overscan[1], $
               crop[0],crop[1],crop[2],crop[3],biasval=biasval)
   print,fname,' overscan value is ',biasval
   sz=size(firstn)
   cube=fltarr(sz[1],sz[2],count,/nozero)
   cube[*,*,0]=firstn
   j=1
   for i=1,nframes-1 do begin
      if frames[i] ne -1 and frames[i] ne firstframe then begin
	      fname=root+string(frames[i],format='(i3.3)')
	      cube[*,*,j] = colbias(readfits(fname,/silent), $
	                       overscan[0],overscan[1], $
	                       crop[0],crop[1],crop[2],crop[3], $
	                       biasval=biasval)
	      print,fname,' overscan value is ',biasval
         j=j+1
      endif
   endfor
endif else if keyword_set(overscan) then begin
   firstn = colbias(first,overscan[0],overscan[1],biasval=biasval)
   print,fname,' overscan value is ',biasval
   sz=size(firstn)
   cube=fltarr(sz[1],sz[2],count,/nozero)
   cube[*,*,0]=firstn
   j=1
   for i=1,nframes-1 do begin
      if frames[i] ne -1 and frames[i] ne firstframe then begin
	      fname=root+string(frames[i],format='(i3.3)')
	      cube[*,*,j] = colbias(readfits(fname,/silent), $
	                       overscan[0],overscan[1],biasval=biasval)
	      print,fname,' overscan value is ',biasval
         j=j+1
      endif
   endfor
endif else if keyword_set(crop) then begin
   firstn = first[crop[0]:crop[1],crop[2]:crop[3]]
   print,fname
   sz=size(firstn)
   cube=fltarr(sz[1],sz[2],count,/nozero)
   cube[*,*,0]=firstn
   j=1
   for i=1,nframes-1 do begin
      if frames[i] ne -1 and frames[i] ne firstframe then begin
	      fname=root+string(frames[i],format='(i3.3)')
	      frame = readfits(fname,/silent)
	      cube[*,*,j] = frame[crop[0]:crop[1],crop[2]:crop[3]]
	      print,fname
         j=j+1
      endif
   endfor
endif else begin
   cube=fltarr(sz[1],sz[2],count,/nozero)
   cube[*,*,0]=first
   j=1
   print,fname
   for i=1,nframes-1 do begin
      if frames[i] ne -1 and frames[i] ne firstframe then begin
         fname=root+string(frames[i],format='(i3.3)')
         cube[*,*,j] = readfits(fname,/silent)
         print,fname
         j=j+1
      endif
   endfor
endelse

avgclip,cube,bias
writefits,root+outsuf,bias,hdr
print,'Saving final bias frame to ',root+outsuf

end
