;+
; NAME: 
;  rdobscod
; PURPOSE:
;  Read standard observatory code data file.
; DESCRIPTION:
; CATEGORY:
;  File I/O
; CALLING SEQUENCE:
;  rdobscod,code,lon,rhosinp,rhocosp,obsname
; INPUTS:
; OPTIONAL INPUT PARAMETERS:
; KEYWORD INPUT PARAMETERS:
; OUTPUTS:
; KEYWORD OUTPUT PARAMETERS:
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;-
pro rdobscod,code,lon,rhosinp,rhocosp,obsname,FILE=file

;on_ioerror,bad

if not keyword_set(file) then begin
   defaultfile=1
   file='/pub/sac0/elgb/data/obscode.dat'
endif else begin
   defaultfile=0
endelse

if defaultfile and not exists(file) then begin
   file='/hall/home/observe/buie/obscode.dat'
endif

if not exists(file) then $
   message,'File '+file+' does not exist, cannot continue.'

openr, lun, file, /get_lun

fmt = '(i6,1x,f8.4,1x,f7.5,1x,f8.5,1x,a60)'
in_obsname=''

maxcodes = 700

code    = intarr(maxcodes)
lon     = fltarr(maxcodes)
rhosinp = fltarr(maxcodes)
rhocosp = fltarr(maxcodes)
obsname = strarr(maxcodes)

npts=0

while (not eof(lun)) do begin

   if npts eq maxcodes then begin
      free_lun, lun
      message, 'Input file is too long, maximum is '+string(maxcodes)+' lines'
      return
   endif

   readf, lun, format=fmt, $
      in_code, in_lon, in_rsp, in_rcp, in_obsname

      code[npts]    = in_code
      lon[npts]     = in_lon
      rhosinp[npts] = in_rsp
      rhocosp[npts] = in_rcp
      obsname[npts] = in_obsname

   npts=npts+1

endwhile

free_lun, lun

print,npts,' observatory codes found in file.'

code    = code[0:npts-1]
lon     = lon[0:npts-1]
rhosinp = rhosinp[0:npts-1]
rhocosp = rhocosp[0:npts-1]
obsname = obsname[0:npts-1]

return

bad:

print,in_code
free_lun, lun
message,'Error reading file.'
return

end
